==> nextcloud-app-tasks-0.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/th.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "สำคัญ",
    "Today" : "วันนี้",
    "Week" : "สัปดาห์",
    "All" : "ทั้งหมด",
    "Current" : "ปัจจุบัน",
    "Completed" : "เสร็จแล้ว",
    "Tasks" : "งาน",
    "Visibility of Smart Collections" : "การมองเห็นของสมาร์ทคอลเลกชัน",
    "Hidden" : "ซ่อนอยู่",
    "Visible" : "มองเห็นได้",
    "Automatic" : "อัตโนมัติ",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Can edit" : "สามารถแก้ไข",
    "Edit" : "แก้ไข",
    "Export" : "ส่งออก",
    "Delete" : "ลบ",
    "Unshare" : "เลิกแชร์",
    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Cancel" : "ยกเลิก",
    "Close" : "ปิด",
    "Select tags to filter by" : "เลือกแท็กที่จะกรอง",
    "Change sort order" : "เปลี่ยนการเรียงลำดับ",
    "Start date" : "วันที่เริ่มต้น",
    "Due date" : "วันที่ครบกำหนด",
    "Priority" : "ลำดับความสำคัญ",
    "Alphabetically" : "เรียงตามตัวอักษร",
    "Manually" : "ด้วยตนเอง",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n งานที่เสร็จแล้ว"],
    "Tomorrow" : "พรุ่งนี้",
    "Details" : "รายละเอียด",
    "Notes" : "โน้ต",
    "Reminders" : "การแจ้งเตือน",
    "Repeat" : "ทำซ้ำ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Task not found!" : "ไม่พบงาน!",
    "Set start date" : "ตั้งวันที่เริ่มต้น",
    "Set due date" : "ตั้งวันที่ครบกำหนด",
    "An error occurred" : "เกิดข้อผิดพลาด"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/th.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "สำคัญ",
    "Today" : "วันนี้",
    "Week" : "สัปดาห์",
    "All" : "ทั้งหมด",
    "Current" : "ปัจจุบัน",
    "Completed" : "เสร็จแล้ว",
    "Tasks" : "งาน",
    "Hidden" : "ซ่อนอยู่",
    "Visible" : "มองเห็นได้",
    "Automatic" : "อัตโนมัติ",
    "Visibility of Smart Collections" : "การมองเห็นของสมาร์ทคอลเลกชัน",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Can edit" : "สามารถแก้ไข",
    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
    "Edit" : "แก้ไข",
    "Export" : "ส่งออก",
    "Delete" : "ลบ",
    "Unshare" : "เลิกแชร์",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Cancel" : "ยกเลิก",
    "Notification" : "การแจ้งเตือน",
    "Email" : "อีเมล",
    "Go back" : "กลับไป",
    "Close" : "ปิด",
    "Select tags to filter by" : "เลือกแท็กที่จะกรอง",
    "Start date" : "วันที่เริ่มต้น",
    "Due date" : "วันที่ครบกำหนด",
    "Priority" : "ลำดับความสำคัญ",
    "Alphabetically" : "เรียงตามตัวอักษร",
    "Tags" : "แท็ก",
    "Manually" : "ด้วยตนเอง",
    "Change sort order" : "เปลี่ยนการเรียงลำดับ",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n งานที่เสร็จแล้ว"],
    "Tomorrow" : "พรุ่งนี้",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Task not found!" : "ไม่พบงาน!",
    "Set start date" : "ตั้งวันที่เริ่มต้น",
    "Set due date" : "ตั้งวันที่ครบกำหนด",
    "Details" : "รายละเอียด",
    "Notes" : "โน้ต",
    "An error occurred" : "เกิดข้อผิดพลาด"
},
"nplurals=1; plural=0;");
